package com.abi.qms.platform.service.impl;

import com.abi.qms.platform.dao.entity.BaseSapMaterial;
import com.abi.qms.platform.dao.entity.QrPackageSapOrder;
import com.abi.qms.platform.dao.entity.QrPackageSapOrderItem;
import com.abi.qms.platform.dao.mapper.BaseSapMaterialMapper;
import com.abi.qms.platform.dao.mapper.QrPackageSapOrderItemMapper;
import com.abi.qms.platform.dao.mapper.QrPackageSapOrderMapper;
import com.abi.qms.platform.dto.req.*;
import com.abi.qms.platform.dto.res.*;
import com.abi.qms.platform.service.SapBaseQueryService;
import com.abi.task.common.utils.PojoConverterUtils;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 * sap基础数据查询
 * </p>
 *
 * @author Andy.Tan
 */
@Service
public class SapBaseQueryServiceImpl implements SapBaseQueryService {

    @Autowired
    private BaseSapMaterialMapper baseSapMaterialMapper;

    @Autowired
    private QrPackageSapOrderMapper qrPackageSapOrderMapper;

    @Autowired
    private QrPackageSapOrderItemMapper qrPackageSapOrderItemMapper;

    /**
     * 查询SAP物料列表
     **/
    @Override
    public ListSapMaterialRes listSapMaterial(ListSapMaterialReq req) {
        //查询
        QueryWrapper<BaseSapMaterial> sapMaterialQw = new QueryWrapper<>();
        sapMaterialQw.like(StringUtils.isNotBlank(req.getSapMaterialId()),"sap_material_id","%"+req.getSapMaterialId()+"%");
        sapMaterialQw.eq("is_delete",0);
        List<BaseSapMaterial> sapMaterialList = baseSapMaterialMapper.selectList(sapMaterialQw);

        //构造出参
        ListSapMaterialRes res = new ListSapMaterialRes();
        List<ListSapMaterialRes.SapMaterialBean> sapMaterialBeanList = PojoConverterUtils.copyList(sapMaterialList, ListSapMaterialRes.SapMaterialBean.class);
        res.setSapMaterialBeanList(sapMaterialBeanList);

        return res;
    }

    /**
     * 查询SAP包材场列表
     **/
    @Override
    public ListSapCoverFactoryRes listSapCoverFactory(ListSapCoverFactoryReq listSapCoverFactoryReq) {
        //TODO
        return null;
    }

    /**
     * 查询SAP啤酒厂列表
     **/
    @Override
    public ListSapBeerFactoryRes listSapBeerFactory(ListSapBeerFactoryReq listSapBeerFactoryReq) {
        //TODO
        return null;
    }

    /**
     * 查询SAP订单列表
     **/
    @Override
    public ListSapCodePackageOrderRes listSapCodePackageOrder(ListSapCodePackageOrderReq req) {
        //查询
        QueryWrapper<QrPackageSapOrder> orderQw = new QueryWrapper<>();
        orderQw.like(StringUtils.isNotBlank(req.getSapOrderNo()),"sap_order_no","%"+req.getSapOrderNo()+"%");
        orderQw.eq("is_delete",0);
        List<QrPackageSapOrder> orderList = qrPackageSapOrderMapper.selectList(orderQw);

        //构造出参
        ListSapCodePackageOrderRes res = new ListSapCodePackageOrderRes();
        List<ListSapCodePackageOrderRes.SapOrderBean> sapOrderBeanList = PojoConverterUtils.copyList(orderList, ListSapCodePackageOrderRes.SapOrderBean.class);
        res.setSapOrderBeanList(sapOrderBeanList);

        return res;
    }

    /**
     * 查询SAP订单关联的QMS物料列表
     **/
    @Override
    public ListMaterialBySapOrderRes listMaterialBySapOrder(ListMaterialBySapOrderReq req) {
        //查询
        QueryWrapper<QrPackageSapOrderItem> orderItemQw = new QueryWrapper<>();
        orderItemQw.eq("sap_order_no",req.getSapOrderNo());
        orderItemQw.eq("is_delete",0);
        List<QrPackageSapOrderItem> sapOrderItemList = qrPackageSapOrderItemMapper.selectList(orderItemQw);

        //构造出参
        ListMaterialBySapOrderRes res = new ListMaterialBySapOrderRes();
        List<ListMaterialBySapOrderRes.OrderItemBean> orderItemBeanList = PojoConverterUtils.copyList(sapOrderItemList, ListMaterialBySapOrderRes.OrderItemBean.class);
        res.setOrderItemBeanList(orderItemBeanList);

        return res;
    }



}
